@@ -19,8 +19,8 @@ device = device.DeviceGenerator()
 
 class Client(Callbacks, SocketHandler):
     def __init__(self, deviceId: str = None, proxies: dict = None, certificatePath = None, socket_trace = False, socketDebugging = False):
-        self.apie = "https://service.narvii.com/api/v1"
-        self.api = "https://aminoapps.com/api-p"
+        self.api = "https://service.narvii.com/api/v1"
+        self.apie = "https://aminoapps.com/api-p"
         self.authenticated = False
         self.configured = False
         self.user_agent = device.user_agent
